@@ -24,13 +24,23 @@ import datetime
 
 # see http://packages.python.org/distribute/setuptools.html#adding-support-for-other-revision-control-systems
 
+class ExecutableNotInstalledException(Exception):
+    """ Copied reahl.component.shelltools to avoid dependency issues"""
+    def __init__(self, executable_name):
+        self.executable_name = executable_name
+    def __str__(self):
+        return "Executable not found: %s" % self.executable_name
+
 
 class Executable(object):
     """ Copied reahl.component.shelltools to avoid dependency issues"""
     
     def __init__(self, name):
         self.name = name
-        self.executable_file = self.which(name)
+
+    @property
+    def executable_file(self):
+        return self.which(self.name)
 
     def which(self, program):
         def is_exe(fpath):
@@ -52,8 +62,8 @@ class Executable(object):
                     if is_exe(candidate):
                         return candidate
 
-        return None
-
+        raise ExecutableNotInstalledException(program)
+        
     def call(self, commandline_arguments, *args, **kwargs):
         return subprocess.call([self.executable_file]+commandline_arguments, *args, **kwargs)
     def check_call(self, commandline_arguments, *args, **kwargs):
@@ -61,6 +71,7 @@ class Executable(object):
     def Popen(self, commandline_arguments, *args, **kwargs):
         return subprocess.Popen([self.executable_file]+commandline_arguments, *args, **kwargs)
 
+
 class Bzr(object):
     def __init__(self, directory):
         self.directory = directory
@@ -133,6 +144,8 @@ class Bzr(object):
                         return False
                     else:
                         logging.error('Error trying to execute "bzr": %s' % ex)
+                except ExecutableNotInstalledException, ex:
+                    pass
                 except Exception, ex:
                     logging.error('Error trying to execute "bzr": %s' % ex)
                 return False
